:orphan:

`plasmapy.analysis.time_series.running_moments`
===============================================

.. currentmodule:: plasmapy.analysis.time_series.running_moments

.. automodapi:: plasmapy.analysis.time_series.running_moments
